import numpy as np
import matplotlib.pylab as plt
import pacsplot as pp
import carmatable as ct
import drpacs

def weatherplot(col,array,antpos,project,cFreq,sFreq,varTimes,varNames,variables):
    scalar = float(cFreq)/float(sFreq)
    
    #rmsIn = ct.CarmaTable()
    #rmsIn.open("finalTimes/finalCorrelation"+"%03i.dat"%(col))
    #rmslistCarma = rmsIn.getFloatCol("CARMA RMS")
    #rmslistCorrected = rmsIn.getFloatCol("Corrected RMS")
    #dict = rmsIn.getDict()

    #timeIn = ct.CarmaTable()
    #timeIn.open("finalTimes/finalTimeHeader.txt")
    #starttimes = timeIn.getCol("Start Time(H:M:S)")
    #endtimes = timeIn.getCol("End Time(H:M:S)")

    tableInc = ct.CarmaTable()
    tableInc.open("carmaphaseDiffs.txt")
    tableIns = ct.CarmaTable()
    tableIns.open("szaphaseDiffsInterpolated.txt")
    times = tableInc.getCol(0)
    sTimes=tableIns.getCol(0)
    cColdata = tableInc.getCol(col)
    sColdata = tableIns.getCol(col)
    cHeaderwords = tableInc.getColNames()
    sHeaderwords = tableIns.getColNames()
    for i in range(len(times)-1,-1,-1):
        if times[i] not in sTimes:
            del times[i]
            del cColdata[i]
    times=[pp.timeToSec(time) for time in times]
    sColdataScaled = []
    for element in sColdata:
        sColdataScaled.append(float(element) * scalar)
    
    rmslistCarma = [] #list of lists
    rmslistCorrected = [] #list of lists
    index = []
    count = 1

    ################ START TIMES AND END TIMES #########
    threshold = 15 #number of seconds that will cause program to think that time interval is a new one
    intervals=[]
    for this,prev in zip(times[1:],times[:-1]):
        if this-prev>threshold:
            intervals.append((prev,this))
    starttimes = [times[0]]
    endtimes = []
    for start,end in intervals:
        starttimes.append(end)
        endtimes.append(start)
    endtimes.append(times[-1])

    ###Start times are when the ranges start, end is same
    ###Use secs past midnight insted of runtime
    for time in starttimes:
        rmslistCarma.append([])
        rmslistCorrected.append([])
        index.append(count)
        count = count + 1

    for (time,c,s) in zip(times,cColdata,sColdataScaled):
        count = 0
        for (sTime,eTime) in zip(starttimes,endtimes):
            if (sTime < time) and (eTime > time):
                rmslistCarma[count].append(int(c))
                rmslistCorrected[count].append(int(c) - int(s))
            count = count +  1

    #
    stdCarmalist = []
    stdCorrectedlist = []
    for (list1,list2) in zip(rmslistCarma,rmslistCorrected):
        stdCarmalist.append(pp.stdev(list1))
        stdCorrectedlist.append(pp.stdev(list2))
    #######

    #!!!!!!!!!!!!!!!!!!!
    rmslistCorrected = stdCorrectedlist[:]
    rmslistCarma = stdCarmalist[:]
    #!!! quick fix to not need to rename variables following this code. should be changed later and change variables below later

    ranges = np.array([starttimes,endtimes])
    ranges[0] = -ranges[0]

    ###
    (junk,minCorr,maxCorr) = pp.normalize(rmslistCorrected)
    (junk,minCar,maxCar) = pp.normalize(rmslistCarma)
    
    rmsCombined = rmslistCorrected + rmslistCarma

    (normalCombined,minComb,maxComb) = pp.normalize(rmsCombined)

    rmslistCorrected = normalCombined[:len(normalCombined)/2] ###take first half slice of combined normalization (Corrected)
    rmslistCarma = normalCombined[len(normalCombined)/2:] ###take second half slice of combined normalization (CARMA)
    #combining RMS CARMA and RMS Corrected for purposes of normalization

    count = 2
    for (varName,varlist) in zip(varNames,variables):
        (normlist,varmin,varmax) = pp.normalize(varlist)
        plt.plot(varTimes,normlist,color=pp.colors(len(varNames)+2)[count],linestyle='-',zorder=1,label=varName+"(%.3f - %.3f)"%(varmin,varmax))
        count = count + 1
    
    #weather var times, one y val per one x val

    plt.errorbar([0]*len(rmslistCorrected),rmslistCorrected,None,ranges,fmt=None,ecolor=pp.colors(len(varNames)+2)[0],elinewidth=3,capsize=4,zorder=2,label="Std(CARMA) (%.3f,%3.f)"%(minComb,maxComb))
    plt.errorbar([0]*len(rmslistCarma),rmslistCarma,None,ranges,fmt=None,ecolor=pp.colors(len(varNames)+2)[1],elinewidth=3,capsize=4,zorder=2,label='Std(CARMA-SZA*%.3f)'%(scalar))

    plt.plot([plt.axis()[0]],[plt.axis()[2]],color=pp.colors(len(varNames)+2)[1],label='Std(CARMA) (%.3f,%.3f)'%(minComb,maxComb))
    plt.plot([plt.axis()[0]],[plt.axis()[2]],color=pp.colors(len(varNames)+2)[0],label='Std(CARMA-SZA*%.3f)'%(scalar))

    plt.axis([min(starttimes),max(endtimes),-0.05,1.2])
    plt.axis([plt.axis()[0]-(plt.axis()[1]-plt.axis()[0])/100,plt.axis()[1]+(plt.axis()[1]-plt.axis()[0])/100,plt.axis()[2],plt.axis()[3]])
    ###pads x coord edges of plot to have 1% blank space
    
    plt.xlabel('Time (Seconds)')
    plt.ylabel('Normalized Value (0-1)')
    #plt.title('Time Versus Weather Variables for CARMA '+dict["cbl"]+'('+dict["cblLen"]+'m) and SZA '+dict["sbl"]+'('+dict["sblLen"]+'m)')

    ###BASELINE LENGTH CALC
    #cblLen = pp.baselineLength(cHeaderwords[col], "carma")
    sblLen = pp.baselineLength(sHeaderwords[col], "sza")
    
    cblLen = pp.baselineLength(cHeaderwords[col], "carma",antpos)
    #sblLen = pp.baselineLength(sHeaderwords[col], "sza",antpos)
    ##########################
    title = "Time Versus Weather Variables for CARMA " + cHeaderwords[col] + "(" + str(int(cblLen)) + " m) and SZA " + sHeaderwords[col] + "(" + str(int(sblLen)) + " m)"
    plt.title(title)
    plt.legend(loc='upper center', ncol=3,mode="expand")

    #plt.text(1.05, 0.5, r"\bf{level set} $\phi$", {'color' : 'g', 'fontsize' : 20},
    #       horizontalalignment = 'left',
    #       verticalalignment = 'center',
    #       rotation = 90,
    #       clip_on = False)
    #plt.text(5, 5, "HELLO WORLD", {'color' : 'k', 'fontsize' : 100})
    #plt.text(1.01, 0.98, "1", {'color' : 'k', 'fontsize' : 20})
    #plt.text(1.01, 0.48, "0", {'color' : 'k', 'fontsize' : 20})
    
    #plt.legend(('Std(CARMA)','Std(CARMA-SZA*%.3f)'%(scalar)),loc='upper left')

def plots(array,antpos,project,cFreq,sFreq):
    
    weatherIn = ct.CarmaTable()
    weatherIn.open("vars.txt")
    times = pp.midnight(weatherIn.getCol("time"))
    varNames = weatherIn.getColNames()
    del varNames[0]
    variables = []
    for var in varNames:  ###for each name in the headers, get the column data
        variables.append(weatherIn.getFloatCol(var))

    count = 0
    for time in times:
        times[count] = pp.timeToSec(time)
        count = count + 1
    
    count = 1
    while (count <= 28):
        plt.figure(num=1, figsize=(14,11), dpi=90)
        weatherplot(count, array, antpos,project,cFreq,sFreq,times,varNames,variables)
        plt.savefig("weather%03i.pdf"%(count), orientation='landscape', bbox_inches='tight', pad_inches=1)
        plt.close(1)
        count = count + 1

