#!/bin/csh -f
# Singledish data reduction script for NGC1333 science observations
# Last update:
# Tue Feb 22 12:50:52 EST 2011 - mwp

echo "WARNING WARNING WARNING  - deprecated script, see do_reduceSD for comments"

onintr Cleanup

set base="cx323"
set obsblock="_89NGC133"

if ( $#argv < 2 ) then
   goto Usage
endif

# trial number
unset trial
# array config
unset ary
# Order of polynomial to fit baseline
set npoly=1
# antennas to discard
unset badants

# get command line parameters
foreach a ( $* )
   set check=`echo $a | awk -F= '{print NF}'`
   if ( "$check" == 2 ) set $a
end

if ( ! $?trial ) then
  echo "You must set a trial number (trial=N)."
  goto Usage
endif

if ( ! $?ary ) then
  echo "You must set a array config (ary=E|D)"
  goto Usage
endif

set dir=$base.1$ary$obsblock.$trial
# Raw uvdata file
set infile=$dir.miriad.fixed
# Spectral data output
set specfile=$base.sd.spec
# Baselined spectral data output
set basefile=$base.sd.base

# On-source position name
set source="SVS13"
# Off-source position name
set off="N1333OFF"

#change to correct directory
cd $dir
echo "$0 $*  # run on `date` " >> 00ScriptRuns


set uvlistout=uvlist.out
set listobsout=listobs.out
set device=/xs

# Location to use as data inspection. Default
# here are the (0,0) positions
set inspectpos="dra(-5,5),ddec(-5,5)"

# Compute antennas to use by removing bad antennas from full list
set antlist = "1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23"
if ( $?badants ) then
    set selectbadants="select=ant("$badants")"
    set bants = ( `echo $badants | tr ',' ' '` )
    foreach ant ( $bants ) 
       set newantlist = " `echo $antlist |sed 's/$ant//' ` "
       set antlist = " $newantlist "
    end
endif
set antennas=( $antlist )

# make a guess nxy to fill all plots on a single page
@ nplots = `calc $#antennas"**".5 | awk '{printf "%d\n",$1}'`
set nx=$nplots
@ nplots ++
set nxy=$nx,$nplots  

# Spectral correlator set up
if ( trial == 2 ) then
    set lines = ( "HCN"  "CONT"  "HC3N" "HCO+" )
else
    set lines = ( "HCN"  "CONT"  "N2H+" "HCO+" )
endif

#goto start
#start:

/bin/rm -rf $infile $infile.USB
cp -pr /data/carma/CARMA23/rawdata/$infile .

if ( $?selectbadants ) then
    uvflag vis=$infile flagval=flag $selectbadants
endif
#uvflag vis=$infile flagval=flag edge=2,2
uvcat vis=$infile out=$infile.USB select=window'(5,6,7,8),source('$source,$off')'

listobs vis=$infile.USB log=$listobsout

/bin/rm -rf $specfile

# Create the Tsys*(ON-OFF)/OFF spectra

sinbad vis=$infile.USB out=$specfile select=auto slop=0.1

/bin/rm -rf $uvlistout
uvlist options=spec vis=$specfile log=$uvlistout

#goto SinPoly
Inspect:
# Inspection of unbaselined data
# Use these plots to determine the emission ranges in channel space, to
# specify as "badchan" ranges in sinpoly.
#
@ w = 1
foreach line ( $lines ) 
 echo "*********************************************************************"
 echo "****** $line dra,ddec = (0,0) individual integrations/antennas ******"
 echo "*********************************************************************"
#    smauvspec vis=$specfile device=$device select=$inspectpos,'win('$w')' \
#           nxy=3,3 axis=chan,real
#    smauvspec vis=$specfile device=$device select='win('$w')' \
#           nxy=3,3 axis=chan,real
 echo "*********************************************************************"
 echo "****** $line dra,ddec = (0,0) all data averaged                ******"
 echo "*********************************************************************"
#    smauvspec vis=$specfile device=$device select=$inspectpos,'win('$w')' \
#           nxy=1,1 axis=chan,real interval=100000 options=avall,nobase
    smauvspec vis=$specfile device=$device select='win('$w')' \
           nxy=1,1 axis=chan,real interval=100000 options=avall,nobase
 sleep 5
@ w++
end

SinPoly:
# Now remove a polynomial baseline from the specta
# Note choosing to display with non-null device is a bit tedious!
/bin/rm -rf $basefile
sinpoly vis=$specfile  out=$basefile options=window npoly=$npoly \
    badchan=4,60,125,180,181,260,320,410,490 \
    endchan=2 nxy=3,3 device=/null

# Inspection of baselined data
@ w = 1
foreach line ( $lines ) 
 echo "*********************************************************************"
 echo "****** BASELINED $line dra,ddec = (0,0) individual integrations/antennas ******"
 echo "*********************************************************************"
    smauvspec vis=$basefile device=$device select=$inspectpos,'win('$w')' \
           nxy=10,10 axis=velo,real
 echo "*********************************************************************"
 echo "****** BASELINED $line dra,ddec = (0,0) all data averaged                ******"
 echo "*********************************************************************"
    smauvspec vis=$basefile device=$device select=$inspectpos,'win('$w')' \
           nxy=1,1 axis=chan,real interval=100000 options=avall,nobase
 sleep 5
@ w++
end


# now make an  maps for each line and antenna
foreach w ( 1 3 4 )
set l=$lines[$w]
set map 
echo SHOWING $l
    foreach ant ( $antennas )
      echo DOING $ant
      /bin/rm -rf $l.$ant.map $l.$ant.ps
      echo $l.$ant.map
      smauvspec vis=$basefile yrange=-.5,5 device=$l.$ant.ps/ps \
           select="ant("$ant")",win"("$w")",$inspectpos nxy=4,2 \
           axis=velo,real line=velo,121,-15,.33,.33 
      smauvspec vis=$basefile yrange=-.5,5 device=$device \
           select="ant("$ant")",win"("$w")",$inspectpos nxy=4,2 axis=velo,real \
           line=velo,121,-15,.33,.33 

      # integrated intensity map
      varmaps vis=$basefile select="ant("$ant")",win"("$w")" zaxis=real \
        options=sum out=$l.$ant.map xcell=30,arcsec ycell=30,arcsec imsize=21,21 \
        line=velo,1,0,20,20 mode=0 size=1 xbeam=30 ybeam=30
      minmax in=$l.$ant.map
      cgdisp in=$l.$ant.map labtyp=arcsec device=/xs options=full
      if ( $ant == 1 ) then
          set map=$l.$ant.map
      else
          set map=$map,$l.$ant.map
      endif
    end
    imcat in=$map out=$l.allants.map options=relax
    set maxval = `minmax in=$l.allants.map |grep maximum |awk '{print $NF}'`
    cgdisp in=$l.allants.map labtyp=arcsec options=abut,full,noepoch csize=0.5,0.5 device=$l.allants.gif/vgif range=0,$maxval,lin,3 nxy=4,5
    cgdisp in=$l.allants.map labtyp=arcsec options=abut,full,noepoch csize=0.5,0.5 device=$l.allants.ps/cps range=0,$maxval,lin,3 nxy=4,5
    cgdisp in=$l.allants.map labtyp=arcsec options=abut,full,noepoch csize=0.5,0.5 device=/xs range=0,$maxval,lin,3 nxy=4,5
end

Cleanup:
exit 0

Usage:
echo "Usage: $0 trial= ary= [npoly=1] [badants=comma-separated-list]"
exit 1
